@@ -9,7 +9,6 @@ def test_Page():
     assert page.amis_html().find(page_json)
 
 
-def test_PageSchema():
-    tmp = PageSchema(schema=Page(), children=[PageSchema()], tmp_field='tmp field')  # type: ignore
-    amis_json = '{"schema":{"type":"page"},"children":[{}],"tmp_field":"tmp field"}'
-    assert tmp.amis_json() == amis_json
+def test_extra_fields():
+    tmp = PageSchema(schema=Page(), children=[PageSchema()], extra_field='extra field')  # type: ignore
+    assert tmp.amis_dict().get('extra_field') == "extra field"
